@@ -12,16 +12,18 @@ import pandas as pd
 import matplotlib
 import matplotlib.pyplot as plt
 
+def dummy():
+    print("hello world")
 
 def cycling_CCCV(file_name,cycle_num):
     '''
-    This function helps the user to plot the battery cycling data for the visualization
+    This function helps the user plot the battery cycling data for the visualization
 
     Parameters
     ----------
   
     file_name : str
-        file name of the file to be read. Should be the battery cycling data..
+        file name of the file to be read. Should be the battery cycling data.
     cycle_num : in
         battery cycle number.
 
@@ -49,12 +51,12 @@ def diff_cap(file_name,cycle_num):
     '''
     
 
-     This function helps the user to plot the differential capacity data for the visualization
+     This function helps the user plot the differential capacity data for the visualization
 
      Parameters
      ----------
      file_name : str
-         file name of the file to be read. Should be the battery cycling data..
+         file name of the file to be read. Should be the battery cycling data.
      cycle_num : in
          battery cycle number.
 
@@ -88,14 +90,14 @@ def diff_cap(file_name,cycle_num):
 def cycling_data_processing(df,cycle_num,data_type):
     '''
     
-    This function hleps user to process the battery cycling data
+    This function helps user to process the battery cycling data
     
     Parameters
     ----------
     df : DataFrame
-        data frame of the battery cycling data.
+        dataframe of the battery cycling data.
     cycle_num : int
-        cycle number interested.
+        cycle number of interest.
     data_type : str
         input 'charge' for the charge data
         input 'discharge' for the discharge data .
@@ -103,14 +105,15 @@ def cycling_data_processing(df,cycle_num,data_type):
     Returns
     -------
     A : DataFrame
-        data frame of the battery cycling data for a certain cycle number.
+        dataframe of the battery cycling data for the cycle number of interest.
 
     '''
     
     if data_type == 'discharge':
-        A=df[(df['Cyc#']==cycle_num)][(df['Current(A)']<0)]
+        A=df[(df['Cyc#']==cycle_num)&(df['Current(A)']<0)]
     if data_type == 'charge':
-        A=df[(df['Cyc#']==cycle_num)][(df['Current(A)']>0)]
+        A=df[(df['Cyc#']==cycle_num)&(df['Current(A)']>0)]
+        
     return (A)
 
 def Capacity_voltage_extract(df):
@@ -120,11 +123,11 @@ def Capacity_voltage_extract(df):
     Parameters
     ----------
     df : DataFrame
-        data frame of the pre processed battery cycling data.
+        dataframe of the pre processed battery cycling data.
 
     Returns
     -------
-    data frame with column 'Capacity(Ah)' and 'Voltage(V)'.
+    dataframe with column 'Capacity(Ah)' and 'Voltage(V)'.
 
     '''
     df_1=pd.DataFrame()
@@ -140,7 +143,7 @@ def impedance_data_processing(text_file):
     Parameters
     ----------
     text_file : str
-        file name of the impedacne data .
+        file name of the impedance data.
 
     Returns
     -------
@@ -168,7 +171,7 @@ def Nyquist_plot_UI(text_file):
     Parameters
     ----------
     text_file : str
-        file name of the impedacne data .
+        file name of the impedance data .
 
     Returns
     -------
@@ -185,7 +188,7 @@ def Nyquist_plot(df):
     Parameters
     ----------
     df : DataFrame
-        data frame that is processed by impedance_data_processing() .
+        dataframe that is processed by impedance_data_processing() .
 
     Returns
     -------
@@ -202,13 +205,13 @@ def Nyquist_plot(df):
     
 def dis_cap(df,max_cycle):
     '''
-
+    
     Parameters
     ----------
     df : DataFrame
-        data frame of batter cycling data.
+        dataframe of battery cycling data.
     max_cycle : in
-        maximum cyle interested .
+        maximum cycle of interest.
 
     Returns
     -------
@@ -224,6 +227,30 @@ def dis_cap(df,max_cycle):
 
     return(cap[-1])
 
-        
+def cap_ret(df,max_cycle):
+    '''
+    
+    Parameters
+    ----------
+    df : DataFrame
+        dataframe of battery cycling data.
+    max_cycle : int
+        maximum cycle of interest.
+
+    Returns
+    -------
+    Capacity retention for all cycles up to the max_cycle
+
+    '''
+    N=max_cycle+1
+    ret=np.zeros(max_cycle)
+    discharge=cycling_data_processing(df,1,'discharge')
+    first_cap=discharge['Capacity(Ah)'].iloc[-1]
+    ret[0]=1
+    for i in range(2,N):
+        discharge=cycling_data_processing(df,i,'discharge')
+        ret[i-1]=(discharge['Capacity(Ah)'].iloc[-1])/first_cap
+
+    return(ret*100)
         
     
